Crate anti_debug

Crate anti_debug 

Anti-Debug

Crate GitHub last commit GitHub issues GitHub pull requests

Description

Provide is_debugger_present detector for windows/linux/android/macos.

Functions

deny_attach
Attempts to prevent debuggers from attaching to the current process.
is_debugger_present
Checks if a debugger is currently attached to the process.